# -*- coding: utf-8 -*-

"""
Use this tool to create, clear, or guarantee that paths exist.
"""

import os
import pathlib
import shutil

__author__ = "Jakrin Juangbhanich"
__email__ = "juangbhanich.k@gmail.com"


def create(path, clear=False):
    """
    Given some arbitrary path, we will create all the directory leading up to it.
    Optionally, we can also clear whatever is there (only at the terminal path).
    """
    _create(path, clear, is_true_tail=True)


def _create(path, clear, is_true_tail):
    head, tail = os.path.split(path)

    # This is the home directory. End it.
    if head == "/" and tail == "":
        return

    # Recursively create the heads.
    if head != "" and head != "~":
        _create(head, clear, is_true_tail=False)

    base, ext = os.path.splitext(tail)
    if ext == "":
        # No extension, this is supposed to be a directory.
        # Clear this if it is the 'head' of the path we are creating.
        if os.path.exists(path) and clear and is_true_tail:
            if path != ".":  # Do NOT attempt to remove the root directory.
                shutil.rmtree(path)

        if not os.path.exists(path):
            pathlib.Path(path).mkdir(parents=True, exist_ok=True)



# -*- coding: utf-8 -*-

"""
Truncates string or JSON data so that it fits a specific number of characters.
"""

__author__ = "Jakrin Juangbhanich"
__email__ = "juangbhanich.k@gmail.com"


def truncate(message: str, max_length: int=128, split_ratio: float=0.8) -> str:
    """ Truncates the message if it is longer than max_length. It will be split at the
    'split_ratio' point, where the remaining last half is added on. """
    if max_length == 0 or len(message) <= max_length:
        return message

    split_index_start = int(max_length * split_ratio)
    split_index_end = max_length - split_index_start
    message_segments = [message[:split_index_start], message[-split_index_end:]]
    return " ... ".join(message_segments)




# -*- coding: utf-8 -*-

__author__ = "Jakrin Juangbhanich"
__email__ = "juangbhanich.k@gmail.com"
__version__ = "0.2.9"

import logmatic.log
from logmatic.log import debug, info, warning, error, critical, increment, gauge, event, get_instance
